@@ -127,10 +127,11 @@ class LinkedinScraper:
                 params['f_E'] = filters
                 debug(tag, 'Applied experience filters', query.options.filters.experience)
 
-            # Remote filter supported only with authenticated session (for now)
-            if query.options.filters.remote is not None and Config.LI_AT_COOKIE:
-                params['f_WRA'] = query.options.filters.remote.value
-                debug(tag, 'Applied remote filter', query.options.filters.remote)
+            # On site/remote filters supported only with authenticated session (for now)
+            if query.options.filters.on_site_or_remote is not None and Config.LI_AT_COOKIE:
+                filters = ','.join(e.value for e in query.options.filters.on_site_or_remote)
+                params['f_WT'] = filters
+                debug(tag, 'Applied on-site/remote filter', query.options.filters.on_site_or_remote)
 
             # Start offset
             params['start'] = '0'
